@@ -1,4 +1,4 @@
-/* $backtrace: backtrace.h,v 1.1 2010/09/09 22:23:45 marco Exp $ */
+/* $backtrace$ */
 /*
  * Copyright (c) 2010 Marco Peereboom <marco@conformal.com>
  * Copyright (c) 2010 Conformal Systems LLC.
@@ -29,13 +29,6 @@ extern "C" {
 
 #include <dlfcn.h>
 
-#define BT_MAX_DEPTH            (128)
-
-struct bt_frame {
-	Dl_info			bt_dlinfo;
-	unsigned int		line;
-};
-
 /* compatability functions with libexecinfo and glibc */
 int			backtrace(void **, int);
 char			**backtrace_symbols(void *const *, int);
@@ -45,4 +38,3 @@ void			backtrace_symbols_fd(void *const *, int, int);
 }
 #endif
 #endif
-
